==> nextcloud-18.0.3.tgz: nextcloud/apps/theming/l10n/ast.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Cargando previsualización...",
    "Saved" : "Guardóse",
    "Admin" : "Almin",
    "a safe home for all your data" : "un llar seguru pa tolos tos datos",
    "Name cannot be empty" : "El nome nun pue tar baleru",
    "The given name is too long" : "El nome dau ye perllargu",
    "The given web address is too long" : "La direición web dada ye perllarga",
    "The given slogan is too long" : "La conseña dada ye perllarga",
    "The given color is invalid" : "El color dau ye perllargu",
    "The file was uploaded" : "Xubióse'l ficheru",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "El ficheru xubíu perpasa la direutiva de xuba upload_max_filesize en php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El ficheru xubíu perpasa la direutiva \"MAX_FILE_SIZE\" especificada nel formulariu HTML",
    "No file was uploaded" : "Nun se xubieron fichjeros",
    "Missing a temporary folder" : "Falta un direutoriu temporal",
    "Could not write file to disk" : "Nun pudo escribise nel discu'l ficheru",
    "A PHP extension stopped the file upload" : "Una estensión de PHP paró la xuba de ficheros",
    "No file uploaded" : "Nun se xubieron ficheros",
    "Unsupported image type" : "Triba non sofitada d'imaxe",
    "Theming" : "Aspeutu",
    "Open documentation" : "Abrir documentación",
    "Name" : "Nome",
    "Slogan" : "Conseña",
    "Color" : "Color",
    "Logo" : "Logu",
    "Upload new logo" : "Xubir logu nuevu",
    "Login image" : "Imaxe d'aniciu de sesión",
    "Upload new login background" : "Xubir fondu nuevu d'aniciu de sesión",
    "Remove background image" : "Desaniciar imaxe de fondu",
    "Advanced options" : "Opciones avanzaes"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-19.0.4.tgz: nextcloud/apps/theming/l10n/ast.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Cargando previsualización...",
    "Saved" : "Guardóse",
    "Admin" : "Almin",
    "a safe home for all your data" : "un llar seguru pa tolos tos datos",
    "Name cannot be empty" : "El nome nun pue tar baleru",
    "The given name is too long" : "El nome dau ye perllargu",
    "The given web address is too long" : "La direición web dada ye perllarga",
    "The given slogan is too long" : "La conseña dada ye perllarga",
    "The given color is invalid" : "El color dau ye perllargu",
    "The file was uploaded" : "Xubióse'l ficheru",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "El ficheru xubíu perpasa la direutiva de xuba upload_max_filesize en php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El ficheru xubíu perpasa la direutiva \"MAX_FILE_SIZE\" especificada nel formulariu HTML",
    "No file was uploaded" : "Nun se xubieron fichjeros",
    "Missing a temporary folder" : "Falta un direutoriu temporal",
    "Could not write file to disk" : "Nun pudo escribise nel discu'l ficheru",
    "A PHP extension stopped the file upload" : "Una estensión de PHP paró la xuba de ficheros",
    "No file uploaded" : "Nun se xubieron ficheros",
    "Theming" : "Aspeutu",
    "Open documentation" : "Abrir documentación",
    "Name" : "Nome",
    "Slogan" : "Conseña",
    "Color" : "Color",
    "Logo" : "Logu",
    "Upload new logo" : "Xubir logu nuevu",
    "Login image" : "Imaxe d'aniciu de sesión",
    "Upload new login background" : "Xubir fondu nuevu d'aniciu de sesión",
    "Remove background image" : "Desaniciar imaxe de fondu",
    "Advanced options" : "Opciones avanzaes",
    "Unsupported image type" : "Triba non sofitada d'imaxe"
},
"nplurals=2; plural=(n != 1);");
